@@ -16,8 +16,8 @@
 #include <string.h>
 #include <typeinfo>
 
+#include "../base/ddcui_core.h"
 #include "../base/nc_values_state.h"
-#include "base/core.h"
 #include "base/global_state.h"
 #include "base/monitor.h"
 #include "base/widget_debug.h"
