@@ -1,6 +1,6 @@
 /** \file main.cpp */
 
-// Copyright (C) 2018-2024 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2018-2025 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <glib-2.0/glib.h>
@@ -30,6 +30,7 @@
 #include "base/ddcui_parms.h"
 #include "base/global_state.h"
 
+#include "main/callback_manager.h"
 #include "main/mainwindow.h"
 #include "main/msgbox_thread.h"
 
@@ -174,39 +175,6 @@ void dbgrpt_hidpiQApplication(QApplication& coreapp) {
 }
 
 
-intmax_t get_thread_id() {
-   pid_t tid = syscall(SYS_gettid);
-   return tid;
-}
-
-
-void create_timestamp(char* buf, int bufsz) {
-   assert(bufsz >= 40);
-   time_t epoch_seconds = time(NULL);
-   struct tm broken_down_time;
-   localtime_r(&epoch_seconds, &broken_down_time);
-   strftime(buf, 40, "%b %d %T", &broken_down_time);
-}
-
-
-void display_status_event_callback(DDCA_Display_Status_Event evt) {
-   char time_buf[40];
-   create_timestamp(time_buf, 40);
-   intmax_t thread_id = get_thread_id();
-  // printf("(%s) evt.dref=%p event_type=%d\n", __func__, evt.dref, evt.event_type);
-
-  printf("[%s][%6jd](main.cpp/%s) Executing. dref=%s, bus=/dev/i2c-%d, event_type = %s\n",
-        time_buf, thread_id, __func__, ddca_dref_repr(evt.dref), evt.io_path.path.i2c_busno, ddca_display_event_type_name(evt.event_type));
-
-  if (evt.dref) {
-     printf("[%s][%6jd](main.cpp/%s) ddca_validate_display_ref(%s) reports: %s\n",
-           time_buf, thread_id, __func__,
-           ddca_dref_repr(evt.dref),
-           ddca_rc_name(ddca_validate_display_ref(evt.dref, true)));
-  }
-}
-
-
 #ifdef UNUSED
 // typedef void (*DDCA_Display_Detection_Callback_Func)(DDCA_Display_Detection_Event);
 void display_detection_callback(DDCA_Display_Detection_Event report) {
@@ -277,7 +245,7 @@ static bool init_ddcutil_library(Parsed_Ddcui_Cmd * parsed_cmd) {
    char ** infomsgs = NULL;
    DDCA_Status rc = ddca_init2(parsed_cmd->library_options, ddcui_syslog_level, opts,  &infomsgs );
    if (debug)
-      printf("(main.cpp:%s) ddca_init() returned %d\n", __func__, rc);
+      printf("(main.cpp:%s) ddca_init2() returned %d\n", __func__, rc);
 
    if (infomsgs) {
       // printf("Null_Terminated_String_Array at %p:\n", (void*) infomsgs);
@@ -291,7 +259,7 @@ static bool init_ddcutil_library(Parsed_Ddcui_Cmd * parsed_cmd) {
       ntsa_free(infomsgs, true);
    }
 
-   if (rc) {
+   if (rc < 0) {
      DDCA_Error_Detail * erec = ddca_get_error_detail();
      if (debug)
         ddca_report_error_detail(erec, 1);
@@ -309,10 +277,6 @@ static bool init_ddcutil_library(Parsed_Ddcui_Cmd * parsed_cmd) {
       // ddca_enable_udf(              parsed_cmd->flags & CMD_FLAG_ENABLE_UDF);
    }
 
-   if (ok && debug) {
-      printf("(main.cpp:%s) Registering callback functions..\n", __func__);
-      ddca_register_display_status_callback(display_status_event_callback);
-   }
 
    if (debug)
       printf("(main.cpp:%s) Done.  Returning %s\n", __func__, SBOOL(ok));
@@ -350,7 +314,7 @@ int main(int argc, char *argv[])
               DDCUTIL_VMAJOR, DDCUTIL_VMINOR, DDCUTIL_VMICRO, QT_VERSION_STR);
        printf("Executing using libddcutil %s, Qt %s\n\n",
               ddca_ddcutil_extended_version_string(), qVersion());
-       puts("Copyright (C) 2018-2024 Sanford Rockowitz");
+       puts("Copyright (C) 2018-2025 Sanford Rockowitz");
        puts("License GPLv2: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>");
        puts("This is free software: you are free to change and redistribute it.");
        puts("There is NO WARRANTY, to the extent permitted by law.");
@@ -364,13 +328,13 @@ int main(int argc, char *argv[])
     else if (vspec.major == 2) {
        if (vspec.minor >=2)
           ok_vspec = true;
-       else if (vspec.minor == 1) {
-          if (vspec.micro >= 3)
-             ok_vspec = true;
-       }
+       // else if (vspec.minor == 1) {
+       //    if (vspec.micro >= 3)
+       //       ok_vspec = true;
+       // }
     }
     if (!ok_vspec) {
-       printf("ddcui requires at least libddcutil version 2.1.3\n");
+       printf("ddcui requires at least libddcutil version 2.2.0\n");
        exit(1);
     }
 
@@ -489,6 +453,7 @@ int main(int argc, char *argv[])
         enable_trace_show_thread_id(parsed_cmd->flags & CMD_FLAG_THREAD_ID_TRACE);
 
        if (!init_ddcutil_library(parsed_cmd)) {
+          printf("init_ddcutil_library() failed\n");
           mainStatus = 1;
        }
        else {
@@ -498,16 +463,19 @@ int main(int argc, char *argv[])
           }
 
           GlobalState & globalState = GlobalState::instance();
+          CallbackManager& callbackManager = CallbackManager::instance();
+          globalState._callbackManager = &callbackManager;
           init_core();
 
           DBGF(debug, "Calling MainWindow constructor", __func__);
           MainWindow w(parsed_cmd);
-          if (debug)
 
           DBGF(debug,"MainWindow constructor completed", __func__);
           globalState._mainWindow = &w;
           globalState._application = &application;
 
+          // callbackManager.registerCallbacks(&w);
+
           // without w.show(), initial serial message box does not appear over MainWindow
           w.show();
 
@@ -526,12 +494,12 @@ int main(int argc, char *argv[])
           // g_snprintf(spid, 40, "grep %ld /proc/locks", get_process_id() );
           // (void) system(spid);
 
-          ddca_show_stats(parsed_cmd->stats_types,
-                          false,              // include_per_thread_data
-                          0);                 // depth
-
-          free_parsed_ddcui_cmd(parsed_cmd);   // make valgrind happier
+          if (parsed_cmd->stats_types)
+             ddca_show_stats(parsed_cmd->stats_types,
+                             false,              // include_per_thread_data
+                             0);                 // depth
        }
+       free_parsed_ddcui_cmd(parsed_cmd);   // make valgrind happier
     }
     application.quit();
     if (test_emit_ddcui_syslog(DDCA_SYSLOG_NOTICE))
