@@ -1,6 +1,6 @@
 /* monitor.cpp */
 
-// Copyright (C) 2018-2023 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2018-2025 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "base/monitor.h"
@@ -59,8 +59,8 @@ Monitor::Monitor(DDCA_Display_Info * display_info, int monitorNumber)
 
 Monitor::~Monitor() {
    bool debug = false;
-   TRACECF(debug, "Starting. monitor=%p, _monitor_number=%d, _displayInfo->dispno=%d, _baseModel=%p",
-         this, _monitorNumber, _displayInfo->dispno, _baseModel);
+   TRACECF(debug, "Starting. monitor=%p, _monitor_number=%d, _displayInfo->dispno=%d, _baseModel=%p, _moninfoPlainText=%p, _capabilitiesPlainTex=%p",
+         this, _monitorNumber, _displayInfo->dispno, _baseModel,  _moninfoPlainText, _capabilitiesPlainText);
 
    if (supportsDdc()) {
       _requestQueue->put(new HaltRequest());
@@ -77,7 +77,9 @@ Monitor::~Monitor() {
       delete _requestQueue;
       delete _vcpThread;
       delete _baseModel;
+      delete _moninfoPlainText;
    }
+   delete _featuresScrollAreaView;
    ddca_free_display_info(_displayInfo);
    TRACECF(debug, "Done");
    free((void*) _cls);
@@ -185,7 +187,7 @@ void Monitor::putVcpRequest(VcpRequest * rqst) {
 
 // never called!
 void Monitor::vcpThreadFinished() {
-   bool debug = true;
+   bool debug =  true;
    TRACECF(debug, "vcp thread finished");
 }
 
